@@ -131,6 +131,8 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 	stickynotes->applets = NULL;
 	stickynotes->last_timeout_data = 0;
 
+	g_set_application_name (_("Sticky Notes"));
+
 	/* Register size for icons */
 	gtk_icon_size_register ("stickynotes_icon_size", 8,8);
 
@@ -151,7 +153,6 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 	stickynotes_make_prelight_icon (stickynotes->icon_prelight,
 			stickynotes->icon_normal, 30);
 	stickynotes->gconf = gconf_client_get_default();
-	stickynotes->tooltips = gtk_tooltips_new();
 
 	stickynotes_applet_init_icons();
 	stickynotes_applet_init_prefs();
@@ -206,35 +207,37 @@ void stickynotes_applet_init_icons(void)
 
 void stickynotes_applet_init_prefs(void)
 {
-	stickynotes->prefs = glade_xml_new (GLADE_PATH, "preferences_dialog",
-			NULL);
 
-	stickynotes->w_prefs = glade_xml_get_widget (stickynotes->prefs,
-			"preferences_dialog");
+	stickynotes->builder = gtk_builder_new ();
+
+        gtk_builder_add_from_file (stickynotes->builder, BUILDER_PATH, NULL);
+
+	stickynotes->w_prefs = GTK_WIDGET (gtk_builder_get_object (stickynotes->builder,
+			"preferences_dialog"));
+
 	stickynotes->w_prefs_width = gtk_spin_button_get_adjustment (
-			GTK_SPIN_BUTTON (glade_xml_get_widget (
-					stickynotes->prefs, "width_spin")));
+			GTK_SPIN_BUTTON (gtk_builder_get_object (
+                                         stickynotes->builder, "width_spin")));
 	stickynotes->w_prefs_height = gtk_spin_button_get_adjustment (
-			GTK_SPIN_BUTTON (glade_xml_get_widget (
-					stickynotes->prefs, "height_spin")));
-	stickynotes->w_prefs_color = glade_xml_get_widget (stickynotes->prefs,
-			"default_color");
-	stickynotes->w_prefs_font_color = glade_xml_get_widget (
-			stickynotes->prefs,
-			"font_color");
+			GTK_SPIN_BUTTON (gtk_builder_get_object (
+                                         stickynotes->builder, "height_spin")));
+	stickynotes->w_prefs_color = GTK_WIDGET (gtk_builder_get_object (stickynotes->builder,
+			"default_color"));
+	stickynotes->w_prefs_font_color = GTK_WIDGET (gtk_builder_get_object (stickynotes->builder,
+			"font_color"));
 	stickynotes->w_prefs_sys_color = GTK_WIDGET (&GTK_CHECK_BUTTON (
-				glade_xml_get_widget (stickynotes->prefs,
+				        gtk_builder_get_object (stickynotes->builder,
 					"sys_color_check"))->toggle_button);
-	stickynotes->w_prefs_font = glade_xml_get_widget (stickynotes->prefs,
-			"default_font");
+	stickynotes->w_prefs_font = GTK_WIDGET (gtk_builder_get_object (stickynotes->builder,
+			"default_font"));
 	stickynotes->w_prefs_sys_font = GTK_WIDGET (&GTK_CHECK_BUTTON (
-				glade_xml_get_widget (stickynotes->prefs,
+				        gtk_builder_get_object (stickynotes->builder,
 					"sys_font_check"))->toggle_button);
 	stickynotes->w_prefs_sticky = GTK_WIDGET (&GTK_CHECK_BUTTON (
-				glade_xml_get_widget (stickynotes->prefs,
+				        gtk_builder_get_object (stickynotes->builder,
 					"sticky_check"))->toggle_button);
 	stickynotes->w_prefs_force = GTK_WIDGET (&GTK_CHECK_BUTTON (
-				glade_xml_get_widget (stickynotes->prefs,
+				        gtk_builder_get_object (stickynotes->builder,
 					"force_default_check"))->toggle_button);
 
 	g_signal_connect (G_OBJECT (stickynotes->w_prefs), "response",
@@ -266,9 +269,9 @@ void stickynotes_applet_init_prefs(void)
 	{
 		GtkSizeGroup *group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 
-		gtk_size_group_add_widget(group, glade_xml_get_widget(stickynotes->prefs, "width_label"));
-		gtk_size_group_add_widget(group, glade_xml_get_widget(stickynotes->prefs, "height_label"));
-		gtk_size_group_add_widget(group, glade_xml_get_widget(stickynotes->prefs, "color_label"));
+		gtk_size_group_add_widget(group, GTK_WIDGET (gtk_builder_get_object (stickynotes->builder, "width_label")));
+		gtk_size_group_add_widget(group, GTK_WIDGET (gtk_builder_get_object (stickynotes->builder, "height_label")));
+		gtk_size_group_add_widget(group, GTK_WIDGET (gtk_builder_get_object (stickynotes->builder, "color_label")));
 
 		g_object_unref(group);
 	}
@@ -276,36 +279,36 @@ void stickynotes_applet_init_prefs(void)
 	if (!gconf_client_key_is_writable(stickynotes->gconf,
 				GCONF_PATH "/defaults/width", NULL))
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-					stickynotes->prefs, "width_label"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+					stickynotes->builder, "width_label")),
 				FALSE);
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-					stickynotes->prefs, "width_spin"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+					stickynotes->builder, "width_spin")),
 				FALSE);
 	}
 	if (!gconf_client_key_is_writable (stickynotes->gconf,
 				GCONF_PATH "/defaults/height", NULL))
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-					stickynotes->prefs, "height_label"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+					stickynotes->builder, "height_label")),
 				FALSE);
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-					stickynotes->prefs, "height_spin"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+					stickynotes->builder, "height_spin")),
 				FALSE);
 	}
 	if (!gconf_client_key_is_writable (stickynotes->gconf,
 				GCONF_PATH "/defaults/color", NULL))
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-					stickynotes->prefs, "color_label"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+					stickynotes->builder, "color_label")),
 				FALSE);
 		gtk_widget_set_sensitive (stickynotes->w_prefs_color, FALSE);
 	}
 	if (!gconf_client_key_is_writable (stickynotes->gconf,
 				GCONF_PATH "/defaults/font_color", NULL))
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-					stickynotes->prefs, "font_color_label"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+					stickynotes->builder, "font_color_label")),
 				FALSE);
 		gtk_widget_set_sensitive (stickynotes->w_prefs_font_color,
 				FALSE);
@@ -317,8 +320,8 @@ void stickynotes_applet_init_prefs(void)
 	if (!gconf_client_key_is_writable (stickynotes->gconf,
 				GCONF_PATH "/defaults/font", NULL))
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-					stickynotes->prefs, "font_label"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+					stickynotes->builder, "font_label")),
 				FALSE);
 		gtk_widget_set_sensitive (stickynotes->w_prefs_font, FALSE);
 	}
@@ -347,7 +350,6 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	/* Initialize Sticky Notes Applet */
 	applet->w_applet = GTK_WIDGET(panel_applet);
 	applet->w_image = gtk_image_new();
-	applet->about_dialog = NULL;
 	applet->destroy_all_dialog = NULL;
 	applet->prelighted = FALSE;
 	applet->pressed = FALSE;
@@ -421,16 +423,19 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 
 	gint size = applet->panel_size;
 
+        if (size > 3)
+           size = size -3;
+
 	/* Choose appropriate icon and size it */
 	if (applet->prelighted)
-	    	pixbuf1 = gdk_pixbuf_scale_simple(stickynotes->icon_prelight, size - 3, size - 3, GDK_INTERP_BILINEAR);
+	    	pixbuf1 = gdk_pixbuf_scale_simple(stickynotes->icon_prelight, size, size, GDK_INTERP_BILINEAR);
 	else
-	    	pixbuf1 = gdk_pixbuf_scale_simple(stickynotes->icon_normal, size - 3, size - 3, GDK_INTERP_BILINEAR);
+	    	pixbuf1 = gdk_pixbuf_scale_simple(stickynotes->icon_normal, size, size, GDK_INTERP_BILINEAR);
 	
 	/* Shift the icon if pressed */
 	pixbuf2 = gdk_pixbuf_copy(pixbuf1);
 	if (applet->pressed)
-		gdk_pixbuf_scale(pixbuf1, pixbuf2, 0, 0, size - 3, size - 3, 1, 1, 1, 1, GDK_INTERP_BILINEAR);
+		gdk_pixbuf_scale(pixbuf1, pixbuf2, 0, 0, size, size, 1, 1, 1, 1, GDK_INTERP_BILINEAR);
 
 	/* Apply the finished pixbuf to the applet image */
 	gtk_image_set_from_pixbuf(GTK_IMAGE(applet->w_image), pixbuf2);
@@ -518,8 +523,8 @@ stickynotes_applet_update_prefs (void)
 	if (gconf_client_key_is_writable (stickynotes->gconf,
 				GCONF_PATH "/defaults/color", NULL))
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-				stickynotes->prefs, "color_label"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+				stickynotes->builder, "color_label")),
 				!sys_color);
 		gtk_widget_set_sensitive (stickynotes->w_prefs_color,
 				!sys_color);
@@ -527,8 +532,8 @@ stickynotes_applet_update_prefs (void)
 	if (gconf_client_key_is_writable (stickynotes->gconf,
 				GCONF_PATH "/defaults/font_color", NULL))
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-				stickynotes->prefs, "font_color_label"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+				stickynotes->builder, "font_color_label")),
 				!sys_color);
 		gtk_widget_set_sensitive (stickynotes->w_prefs_font_color,
 				!sys_color);
@@ -536,8 +541,8 @@ stickynotes_applet_update_prefs (void)
 	if (gconf_client_key_is_writable (stickynotes->gconf,
 				GCONF_PATH "/defaults/font", NULL))
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-				stickynotes->prefs, "font_label"),
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+				stickynotes->builder, "font_label")),
 				!sys_font);
 		gtk_widget_set_sensitive (stickynotes->w_prefs_font,
 				!sys_font);
@@ -588,8 +593,7 @@ stickynotes_applet_update_tooltips (void)
 	for (l = stickynotes->applets; l; l = l->next)
 	{
 		applet = l->data;
-		gtk_tooltips_set_tip (stickynotes->tooltips,
-				applet->w_applet, tooltip, NULL);
+		gtk_widget_set_tooltip_text (applet->w_applet, tooltip);
 	
 		if (applet->menu_tip)
 			gtk_label_set_text (GTK_LABEL (gtk_bin_get_child (
